1.2. Installation — PyPAGO 1.0.1 documentation

# 1.2. Installation

## 1.2.1. Using subversion

### 1.2.1.1. Download the code

The code is hosted on a SVN repository. It can be downloaded as follows:

    svn checkout https://subversion.renater.fr/pago/trunk

The code can be updated as follows:

    svn update

### 1.2.1.2. Install the code

In your `.bashrc` file, add the destination directory to your `PYTHONPATH`:

    export PYTHONPATH=$PYTHONPATH:/home/nbarrier/Bureau/test_pypago/lib/python

Note

You must add `lib/python` at the end of your destination directory

Then, from the `pago` directory, run the `setup.py` file as follows:

    python setup.py install --home=/home/nbarrier/Bureau/test_pypago

Finally, in your `.bashrc` file, add the location of the `bin` directory to your `PATH`:

    export PATH=$PATH:/home/nbarrier/Bureau/test_pypago/bin

The latter will allow you to run the different executable scripts that come with PyPAGO